==> flexi_style-1.1.0.tar.gz: flexi_style/README.md <==
## Table of contents

- Introduction
- Requirements
- Installation
- Configuration
- Features
- Maintainers

## Introduction
The "FlexiStyle" theme is based on CSS, in this theme we are
not using any base theme. This theme is fully responsive
and mobile-first. In this theme, we have added the
latest version of the font-awesome library for icons. This
theme is partial and component based. We have created the
CSS files based on the component. We have created all the
recommended twigs. That's why this theme is lightweight.
We have added `'hook_theme_suggestions_HOOK_alter'` in
`flexi_style.theme` file for a better understanding of the
twigs and suggestions. This theme does not render unnecessary
CSS and JS libraries from core and contrib modules.
Configuration is also added in the theme, for the system
or core blocks enabling in the particular regions. Some of
the common and recommended blocks should be enabled
automatically in the theme. I will recommend you all for
installing this `FlexiStyle` theme for the best site
performance and best UI.


In this theme, we have designed the core pages such as:
- 404 - page not found
- 403 - Access Denied
- Maintenance Page
- User profile page
- User login page
- User register page
- Forgot password page
- Search result page
- Forums page
- Taxonomy term pages
- Content type pages
- Comments
- Contact forms
- Webforms
- Views


## Requirements

This theme requires Drupal core `>= 9.0`.
This theme does not require any theme and modules outside of Drupal core.


## Installation

Install as you would normally install a contributed Drupal theme.
Install with composer: `composer require drupal/flexi_style` then enable the theme.


## Configuration

Go to the Administration » Appearance.
On the same page "FlexiStyle" theme and click on the install and set as default.

## Features

- User-defined column widths
- Container and container-fluid (full width) layout.
- Flexbox CSS property for the layout and structure.
- Easy to customize twig templates.
- Body classes for entities, users, and roles
- Custom styling editor (`Custom CSS`) from UI.
- Variable file to change the theme color and other components UI.
- Subtheme overrides and replaces every CSS from Drupal.
- Override common and recommended twig templates and pre-process functions.
- Theme-settings file for managing the setting of the theme.
- This theme is based on atomic design patterns and classes.
- The theme follows the components-based twig and CSS.
- Mathematical functions in the CSS to manage the color and sizes.
- Lightweight.
- Fully responsive and mobile-friendly.
- Cross-browser-compatible.
- Progressive Web Apps (PWA) capability support.
- 403 access denied and 404 page not found pages designed accordingly.
- Mantainence page design capability.
- Custom scrollbar
- Flexibility to change the sitewide theme color from variable.css.
- Dismissable alert messages.
- Use predefined classes for the perfect UI.
- The performance score is 90+.
- Attach libraries based on the components.


## Maintainers

- Anoop Singh - [anoopsingh92](https://www.drupal.org/u/anoopsingh92)

==> flexi_style-1.2.4.tar.gz: flexi_style/README.md <==
## Table of contents

- Introduction
- Requirements
- Installation
- Configuration
- Features
- Maintainers

## Introduction
The "FlexiStyle" theme is based on CSS, in this theme we are
not using any base theme. This theme is fully responsive
and mobile-first. In this theme, we have added the
latest version of the font-awesome library for icons. This
theme is partial and component based. We have created the
CSS files based on the component. We have created all the
recommended twigs. That's why this theme is lightweight.
We have added `'hook_theme_suggestions_HOOK_alter'` in
`flexi_style.theme` file for a better understanding of the
twigs and suggestions. This theme does not render unnecessary
CSS and JS libraries from core and contrib modules.
Configuration is also added in the theme, for the system
or core blocks enabling in the particular regions. Some of
the common and recommended blocks should be enabled
automatically in the theme. I will recommend you all for
installing this `FlexiStyle` theme for the best site
performance and best UI.


In this theme, we have designed the core pages such as:
- 404 - page not found
- 403 - Access Denied
- Maintenance Page
- User profile page
- User login page
- User register page
- Forgot password page
- Search result page
- Forums page
- Taxonomy term pages
- Content type pages
- Comments
- Contact forms
- Webforms
- Views


## Requirements

This theme requires Drupal core `>= 9.0`.
This theme does not require any theme and modules outside of Drupal core.


## Installation

Install as you would normally install a contributed Drupal theme.
Install with composer: `composer require drupal/flexi_style`
then enable the theme.


## Configuration

Go to the Administration » Appearance.
On the same page "FlexiStyle" theme and click on the install and set as default.

## Features

- User-defined column widths
- Container and container-fluid (full width) layout.
- Flexbox CSS property for the layout and structure.
- Easy to customize twig templates.
- Body classes for entities, users, and roles
- Custom styling editor (`Custom CSS`) from UI.
- Variable file to change the theme color and other components UI.
- Subtheme overrides and replaces every CSS from Drupal.
- Override common and recommended twig templates and pre-process functions.
- Theme-settings file for managing the setting of the theme.
- This theme is based on atomic design patterns and classes.
- The theme follows the components-based twig and CSS.
- Mathematical functions in the CSS to manage the color and sizes.
- Lightweight.
- Fully responsive and mobile-friendly.
- Cross-browser-compatible.
- Progressive Web Apps (PWA) capability support.
- 403 access denied and 404 page not found pages designed accordingly.
- Mantainence page design capability.
- Custom scrollbar
- Flexibility to change the sitewide theme color from variable.css.
- Dismissable alert messages.
- Use predefined classes for the perfect UI.
- The performance score is 90+.
- Attach libraries based on the components.


## Maintainers

- Anoop Singh - [anoopsingh92](https://www.drupal.org/u/anoopsingh92)
